==> dclib-0.3.17.tar.bz2: dclib-0.3.17/dclib/core/cmanager.h <==
/***************************************************************************
                           cmanager.h  -  description
                             -------------------
    begin                : Thu Jan 23 2003
    copyright            : (C) 2003 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CMANAGER_H
#define CMANAGER_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/cobject.h>
#include <dclib/core/clist.h>
#include <dclib/core/ccallback.h>
#include <dclib/core/csingleton.h>

class CManager;

#ifdef WIN32
template class DLL_EXPORT CSingleton<CManager>;
#endif

class DLL_EXPORT CManager : public CSingleton<CManager>, public CThread {
public:
	/** */
	CManager();
	/** */
	virtual ~CManager();

	/** */
	void Add( _CCallback * callback );
	/** */
	void Remove( _CCallback * callback );

	/** */
	virtual void Thread( CObject * pObject );

private:
	/** */
	friend class CSingleton<CManager>;

	/** */
	CThreadList<_CCallback> m_ThreadList;
};

#endif

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/core/cmanager.h <==
/***************************************************************************
                           cmanager.h  -  description
                             -------------------
    begin                : Thu Jan 23 2003
    copyright            : (C) 2003 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CMANAGER_H
#define CMANAGER_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/clist.h>
#include <dclib/core/csingleton.h>
#include <dclib/core/cmutex.h>
#include <dclib/core/cthread.h>

class _CCallback0;
class CManager;

#ifdef WIN32
template class DLL_EXPORT CSingleton<CManager>;
template class DLL_EXPORT CList<_CCallback0>;
#endif

class DLL_EXPORT CManager : public CSingleton<CManager>, public CThread {
public:
	/** */
	CManager();
	/** */
	virtual ~CManager();

	/** */
	void Add( _CCallback0 * callback );
	/** */
	void Remove( _CCallback0 * callback );

	/** */
	virtual void Thread();

private:
	/** */
	CMutex m_CallbacksMutex;
	/** */
	CList<_CCallback0> m_Callbacks;
};

#endif
